@@ -281,8 +281,12 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     time_t event_end_time = (*event_iter)->getDateEnd();
     time_t event_time_offset = (*event_iter)->getTzOffset();
     struct tm* time = localtime(&event_start_time);
-    event_end_time += event_time_offset - system_time_offset;
-    event_start_time += event_time_offset - system_time_offset;
+    if(CMulticalendar::MCInstance()->getSystemTimeZone() != (*event_iter)->getTzid() &&
+       (*event_iter)->getAllDay())
+    {
+      event_end_time += event_time_offset - system_time_offset;
+      event_start_time += event_time_offset - system_time_offset;
+    }
     char buf[255];
     if(cal_date_on_today(event_start_time, desktop_plugin) || 
        (event_start_time <= date_today_time && (event_end_time == -1 || event_end_time >= date_today_time)))
@@ -399,9 +403,7 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
 	   (calendars_components[k]->getType() == E_TODO))) ||
 	 (birthday_only && (calendars_components[k]->getType() == E_EVENT)) ||
 	 (desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK && calendars_components[k]->getType() != E_TODO) ||
-	 (component->getType() == E_TODO && component->getDateStart() > end_time) ||
-	 (component->getType() == E_EVENT && ((component->getDateEnd() + (event_time_offset-system_time_offset))<
-	 start_time))
+	 (component->getType() == E_TODO && component->getDateStart() > end_time)
 	 )
       {
 	delete calendars_components[k];
